/*

Copyright (c) Bridgetek Pte Ltd

THIS SOFTWARE IS PROVIDED BY BRIDGETEK PTE LTD "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
BRIDGETEK PTE LTD BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
OF SUBSTITUTE GOODS OR SERVICES LOSS OF USE, DATA, OR PROFITS OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

BRIDGETEK DRIVERS MAY BE USED ONLY IN CONJUNCTION WITH PRODUCTS BASED ON BRIDGETEK PARTS.

BRIDGETEK DRIVERS MAY BE DISTRIBUTED IN ANY FORM AS LONG AS LICENSE INFORMATION IS NOT MODIFIED.

IF A CUSTOM VENDOR ID AND/OR PRODUCT ID OR DESCRIPTION STRING ARE USED, IT IS THE
RESPONSIBILITY OF THE PRODUCT MANUFACTURER TO MAINTAIN ANY CHANGES AND SUBSEQUENT WHQL
RE-CERTIFICATION AS A RESULT OF MAKING THESE CHANGES.

Abstract:

This file contains is functions for all UI fields.

Author : BRIDGETEK 

Revision History: 
0.1 - date 2013.04.24 - initial version
0.2 - date 2014.04.28 - Split in individual files according to platform
1.0 - date 2014.11.24 - Addition of FT81x
1.1 - date 2015.04.15 - Introduction of module specific configurations
*/

#ifndef _PLATFORM_H_
#define _PLATFORM_H_

//RJA Specify the LCD resolution and touchscreen type here
//RJA going to heavily edit this to include P2 specific things
//RJA removing Arduino and FTDI LCD module specific things



////RJA Define SPI interface pins here
//RJA's P2 Board1
//#define FT800_CS                                (30)
//#define FT800_INT                               (28)
//#define FT800_PD_N                              (31)
//#define FT800_SEL_PIN           FT800_CS
////RJA adding more pins
//#define FT800_MOSI   (24)
//#define FT800_MISO   (25)
//#define FT800_CLK    (29)

//RJA Define SPI interface pins here
//P2 Eval board with makeshift adapter
#define FT800_CS                                (48+5)
#define FT800_INT                               (48+7) //not actually connected on RJA's makeshift adapter
#define FT800_PD_N                              (48+6)
#define FT800_SEL_PIN           FT800_CS
//RJA adding more pins
#define FT800_MOSI								(48+0)
#define FT800_MISO								(48+1)
#define FT800_CLK								(48+4)

//Pick one or none of these to say where files might come from
#define USE_SD
//#define USE_HOST


//RJA:  Pick display resolution here
/* Custom configuration set by the user */
//#define DISPLAY_RESOLUTION_QVGA                     (1)
#define DISPLAY_RESOLUTION_WQVGA                    (1)
//#define DISPLAY_RESOLUTION_WVGA                     (1)
//#define DISPLAY_RESOLUTION_HVGA_PORTRAIT            (1)

//RJA:  Pick the chip you are using here
/* Chip configuration specific macros */
//#define FT800_ENABLE                            (1)
//#define FT801_ENABLE                            (1)
//#define FT810_ENABLE                            (1)
//#define FT811_ENABLE                            (1)
#define FT812_ENABLE                            (1)
//#define FT813_ENABLE                            (1)

//RJA:  Pick SPI bus width here
/* SPI specific macros - compile time switches for SPI single, dial and quad use cases */
#define ENABLE_SPI_SINGLE                          (1)
//#define ENABLE_SPI_DUAL                            (1)
//#define ENABLE_SPI_QUAD                            (1)


/* Threshold for resistance */
#define RESISTANCE_THRESHOLD                    (1200) //RJA:  What is this?  for resistive touch panels?



#if (defined(FT800_ENABLE) || defined(FT801_ENABLE))
#define FT80X_ENABLE                                (1)
#endif

#if (defined(FT810_ENABLE) || defined(FT811_ENABLE) || defined(FT812_ENABLE) || defined(FT813_ENABLE))
#define FT81X_ENABLE                                (1)
#endif

/* Type of file to load from SDCard or Windows file system */
#define LOADIMAGE 1  //loadimage command takes destination address and options before the actual bitmap data
#define INFLATE 2    //inflate command takes destination address before the actual bitmap
#define LOAD 3       //load bitmaps directly



//typedef boolean bool_t;
#define TRUE     (1)
#define FALSE    (0)

#include "propeller2.h"

#include "stdio.h"
#include "stdlib.h"

////RJA:  Redefine uSD pins if necessary
//#define pin_sd_miso 44
//#define pin_sd_mosi 46
//#define pin_sd_cs 47
//#define pin_sd_clk 45
//#define PIN_SS   pin_sd_cs//60
//#define PIN_MOSI pin_sd_mosi//59
//#define PIN_MISO pin_sd_miso//58
//#define PIN_CLK  pin_sd_clk//61

#include "stdint.h"


//RJA:  A lot of types not defined in FlexC...  Also removed a lot of "prog", Arduino specific type stuff throughout
//#define bool_t int
//#define char8_t char
//#define uchar8_t uchar
//#define byte char
//#define uchar unsigned char
//#define float_t float

typedef char  byte;
typedef unsigned char uchar;
typedef char		bool_t;
typedef char		char8_t;
typedef unsigned char	uchar8_t;
typedef unsigned char prog_uchar8_t;
typedef signed char	schar8_t;
typedef float		float_t;




#include "Gpu_Hal.h"
#include "Gpu_Hal.cpp"



#include "CoPro_Cmds.h"
#include "CoPro_Cmds.cpp"

#include "Gpu.h"

#include "Hal_Utils.h"
#include "Hal_Utils.cpp"

/* Global used for context hal */
Gpu_Hal_Context_t host, * phost;

#include "App_Common.h"


#include "App_Common.cpp"




#endif /*_PLATFORM_H_*/
/* Nothing beyond this*/




